@@ -13,7 +13,11 @@ NULL
 #' @param linetype line type.
 #' @param plot_type plot type. Allowed values are one of "b" for both line and point;
 #' "l" for line only; and "p" for point only. Default is "b".
+#' @param size line size. Deprecated in ggplot2 v >= 3.4.0, use \code{linewidth} instead.
+#' @param linewidth line width. Default is 0.5. Recommended parameter for
+#' ggplot2 version >= 3.4.0. If both \code{size} and \code{linewidth} are specified, an error is thrown.
 #' @param shape point shapes.
+#' @param stroke point stroke. Used only for shapes 21-24 to control the thickness of points border.
 #' @param show.line.label logical value. If TRUE, shows line labels.
 #' @param point.size point size.
 #' @param point.color point color.
@@ -123,7 +127,9 @@ ggline<- function(data, x, y, group = 1,
                   color = "black", palette = NULL,
                   linetype = "solid",
                   plot_type = c("b", "l", "p"),
-                  size = 0.5, shape = 19, point.size = size, point.color = color,
+                  size = NULL, linewidth = NULL, 
+                  shape = 19, stroke = NULL,
+                  point.size = linewidth, point.color = color,
                   title = NULL, xlab = NULL, ylab = NULL,
                   facet.by = NULL, panel.labs = NULL, short.panel.labs = TRUE,
                   select = NULL, remove = NULL, order = NULL,
@@ -133,6 +139,7 @@ ggline<- function(data, x, y, group = 1,
                   label = NULL, font.label = list(size = 11, color = "black"),
                   label.select = NULL, repel = FALSE, label.rectangle = FALSE,
                   show.line.label = FALSE,
+                  position = "identity",
                   ggtheme = theme_pubr(),
                   ...)
 {
@@ -145,7 +152,7 @@ ggline<- function(data, x, y, group = 1,
     combine = combine, merge = merge,
     color = color, palette = palette,
     linetype = linetype, plot_type = plot_type,
-    size = size,  shape = shape,
+    size = size,  linewidth = linewidth, shape = shape, stroke = stroke,
     point.size = point.size, point.color = point.color,
     title = title, xlab = xlab, ylab = ylab,
     facet.by = facet.by, panel.labs = panel.labs, short.panel.labs = short.panel.labs,
@@ -153,7 +160,7 @@ ggline<- function(data, x, y, group = 1,
     add = add, add.params = add.params, error.plot = error.plot,
     label = label, font.label = font.label, label.select = label.select,
     repel = repel, label.rectangle = label.rectangle,
-    show.line.label = show.line.label, ggtheme = ggtheme, ...)
+    show.line.label = show.line.label, position = position, ggtheme = ggtheme, ...)
   if(!missing(data)) .opts$data <- data
   if(!missing(x)) .opts$x <- x
   if(!missing(y)) .opts$y <- y
@@ -183,8 +190,9 @@ ggline_core <- function(data, x, y, group = 1,
                   color = "black", fill = "white", palette = NULL,
                   linetype = "solid",
                   plot_type = c("b", "l", "p"),
-                  size = 0.5, shape = 19,
-                  point.size = size, point.color = color,
+                  size = NULL, linewidth = NULL,
+                  shape = 19, stroke = NULL,
+                  point.size = NULL, point.color = color,
                   title = NULL, xlab = NULL, ylab = NULL,
                   select = NULL, order = NULL,
                   facet.by = NULL,
@@ -194,17 +202,33 @@ ggline_core <- function(data, x, y, group = 1,
                   show.line.label = FALSE,
                   font.label = list(size = 11, color = "black"),
                   repel = FALSE, label.rectangle = FALSE,
+                  position = "identity",
                   ggtheme = theme_pubr(),
                       ...)
 {
+
+  # Handle size vs linewidth parameter compatibility
+  # size deprecated in ggplot2 v >= 3.4.0
+  if (!is.null(size) && !is.null(linewidth)) {
+    stop("Please specify either 'size' or 'linewidth', not both. Use 'linewidth' for ggplot2 3.4.0+ compatibility.")
+  } else if (!is.null(size)) {
+    warning("The 'size' parameter for lines is deprecated in ggplot2 3.4.0+. Please use 'linewidth' instead to avoid this warning in future versions.")
+    linewidth <- size  
+  } else if (is.null(linewidth)) {
+    linewidth <- 0.5  # Default value
+  }
+  
+  if(is.null(point.size)){
+    point.size <- if (!is.null(size)) size else if (!is.null(linewidth)) linewidth else 0.5
+  }
+
   xx <- .select_vec(data, x)
   if(inherits(xx, c("character", "numeric")) & !numeric.x.axis)
-    data[, x] <- .select_vec(data, x) %>% as.factor()
+    data[[x]] <- .select_vec(data, x) %>% as.factor()
 
   error.plot = error.plot[1]
   plot_type <- match.arg(plot_type)
   if("none" %in% add) add <- "none"
-  position = "identity"
   grouping.vars <- intersect(c(x, color, linetype, group, facet.by), names(data))
   . <- NULL
 
@@ -238,13 +262,13 @@ ggline_core <- function(data, x, y, group = 1,
     if(is.null(add.params$group)) add.params$group <- group[1]
   }
 
-  p <- ggplot(data, aes_string(x, y))
+  p <- ggplot(data, create_aes(list(x = x, y = y)))
 
   # Add other geom or summary
   #:::::::::::::::::::::::::::::::::::::::
   add.params <- add.params %>%
     .add_item(error.plot = error.plot,
-              position = "identity", p_geom = "geom_line")
+              position = position, p_geom = "geom_line")
 
   # First add geom if any
   p <- add.params %>%
@@ -252,7 +276,7 @@ ggline_core <- function(data, x, y, group = 1,
     do.call(ggadd, .)
   # Then add summary statistics
   p <- add.params %>%
-    .add_item(p = p, size = size, add = intersect(add, .summary_functions())) %>%
+    .add_item(p = p, size = linewidth, linewidth = linewidth, add = intersect(add, .summary_functions())) %>%
     do.call(ggadd, .)
 
 
@@ -267,11 +291,11 @@ ggline_core <- function(data, x, y, group = 1,
                             stat = "identity",
                             color = color, linetype = linetype,
                             position = position,
-                            size = size)
+                            linewidth = linewidth)
     mapping <- line_args$mapping
     mapping[["group"]] <- group
     option <- line_args$option
-    option[["mapping"]] <- do.call(ggplot2::aes_string, mapping)
+    option[["mapping"]] <- create_aes(mapping)
     p <- p + do.call(geom_line, option)
   }
 
@@ -279,7 +303,8 @@ ggline_core <- function(data, x, y, group = 1,
     p <- p +
     geom_exec(geom_point, data = data_sum,
                color = point.color, shape = shape,
-               size = 1.2+point.size)
+               size = 1.2+point.size, stroke = stroke,
+              position = position)
     # Adjust shape when ngroups > 6, to avoid ggplot warnings
     p <-.scale_point_shape(p, data_sum, shape)
   }
